# Test run evidence — xwschema

Per GUIDE_41_DOCS and GUIDE_51_TEST. Test runner writes `TEST_<timestamp>_SUMMARY.md` here.

| Report | Date | Description |
|--------|------|--------------|
| [TEST_20251217_194056_000_CORE_LAYER_RUN.md](TEST_20251217_194056_000_CORE_LAYER_RUN.md) | 2025-12-17 | Core layer run (historical; 1 failed, 15 passed) |
| [TEST_20260208_114608_630_SUMMARY.md](TEST_20260208_114608_630_SUMMARY.md) | 2026-02-08 | Full suite run |
| [TEST_20260208_114727_032_SUMMARY.md](TEST_20260208_114727_032_SUMMARY.md) | 2026-02-08 | Full suite run |

- **REF:** [REF_51_TEST.md](../../REF_51_TEST.md)
- **Runner:** `python tests/runner.py` (writes new TEST_* here)
